@@ -15,42 +15,7 @@
  */
 #include <linux/stat.h>
 #include <linux/types.h>
-#include <linux/version.h>
-
-#ifndef BITS_PER_LONG
-#ifndef __LP64__	/* never build this code LP64! */
-#define BITS_PER_LONG 32
-#endif
-#endif
-
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,4,0)
-
-#  undef __KERNEL__
-#  include <linux/ext2_fs.h>
-#  define __KERNEL__
-#  include <linux/fs.h>
-#  ifndef TESTING
-#    include <linux/string.h>
-#  endif
-
-#else /* Linux 2.4.0 or later */
-
-#  undef __KERNEL__
-#  include <linux/ext2_fs.h>
-#  include <linux/fs.h>
-#  define __KERNEL__
-
-#endif
-
-/* #undef __KERNEL__ */
-#include <asm/byteorder.h>
 #include <linux/ext2_fs.h>
-#include <linux/fs.h>
-/* #define __KERNEL__ */
-
-/* #undef _LINUX_STRING_H_
-#include <linux/string.h> */
-
 #include "bootloader.h"
 
 #define MAX_OPEN_FILES		5
@@ -709,14 +674,13 @@ static int ext2_bread(int fd, long blkno, long nblks, char *buffer)
 	return ext2_breadi(ip, blkno, nblks, buffer);
 }
 
-#if 0
 /*
  * Note: don't mix any kind of file lookup or other I/O with this or
  * you will lose horribly (as it reuses blkbuf)
  */
-static const char * ext2_readdir(int fd, int rewind)
+const char * ext2_readdir(int fd, int rewind)
 {
-	struct ext2_inode * ip = &inode_table[fd].inode;
+	struct ext2_inode * ip = fd2inode[fd];
 	struct ext2_dir_entry_2 * ent;
 	if (!S_ISDIR(ip->i_mode)) {
 		printf("fd %d (inode %d) is not a directory (mode %x)\n",
@@ -731,7 +695,6 @@ static const char * ext2_readdir(int fd, int rewind)
 		return NULL;
 	}
 }
-#endif
 
 int ext2_filesize(int fd)
 {
@@ -857,7 +820,7 @@ int ext2_open(const char *filename)
 }
 
 
-static void ext2_close(int fd)
+void ext2_close(int fd)
 {
 	/* blah, hack, don't close the root inode ever */
 	if (&inode_table[fd].inode != root_inode)
@@ -866,9 +829,13 @@ static void ext2_close(int fd)
 
 
 struct bootfs ext2fs = {
-	0 /* FS_EXT2 */, 0,
-	ext2_mount,
-	ext2_open,  ext2_bread,  ext2_close /* ,
-	ext2_readdir, ext2_fstat */
+	.fs_type =	0,
+	.blocksize =	0,
+	.mount =	ext2_mount,
+	.open =		ext2_open,
+	.bread = 	ext2_bread,
+	.close = 	ext2_close,
+	.readdir =	ext2_readdir,
+	/* .fstat =	ext2_fstat */
 };
 /* $Id: ext2.c,v 1.5 2000/09/21 16:47:48 bame Exp $ */
