@@ -9,9 +9,9 @@
  */
 #include <stdarg.h>
 #include <asm/byteorder.h>
-#include <linux/genhd.h>
+#include "part.h"
 
-#define PALOVERSION "1.5"
+#define PALOVERSION "1.9"
 
 /* size of I/O block used in HP firmware */
 #define FW_BLOCKSIZE	2048
@@ -77,6 +77,7 @@ struct diskpartition
     unsigned char id;
 };
 
+
 #define MAXPARTS 16
 
 int seekread(int fd, char *buf, unsigned nbytes, unsigned devaddr);
