@@ -89,7 +89,11 @@ static char *errormessages[] = {
 	"or a ramdisk.\n",
 
 	/* 19 */
-	"mke2fs failed, exit code %d."
+	"mke2fs failed, exit code %d.",
+
+	/* 20 */
+	"Cannot update an uninitialized ext2/3 formatted partition.\n"
+
 };
 
 #define NMESSAGES (sizeof errormessages / sizeof errormessages[0])
